@@ -5,8 +5,9 @@ class Constants:
     # --------------------------------------------------- Public properties -------------------------------------------------- #
 
     USER_AGENT_FILE_NAME        = 'ua.txt'
-    GENERAL_COOKIES_FOLDER_NAME = 'python-selenium_browser-cookies'
-    DEFAULT_COOKIES_ID          = 'test'
+    GENERAL_COOKIES_FOLDER_NAME = 'cookies'
+    GENERAL_PROFILE_FOLDER_NAME = 'selenium-python-profile'
+    DEFAULT_PROFILE_ID          = 'test'
     DEFAULT_FIND_FUNC_TIMEOUT   = 2.5
 
 
